--
-- Create Schema Script 
--   Database Version   : 11.2.0.2.0 
--   Toad Version       : 10.6.1.3 
--   DB Connect String  : XE 
--   Schema             : UOC 
--   Script Created by  : UOC 
--   Script Created at  : 1/14/2013 9:44:43 PM 
--   Physical Location  :  
--   Notes              :  
--

-- Object Counts: 
--   Directories: 0 
--   Functions: 4       Lines of Code: 106 


CREATE OR REPLACE FUNCTION     FUN_ENCRIPTA (VALOR VARCHAR2) RETURN VARCHAR2 IS
    --
    -- DESCRIPCIN: Funcin de encriptacin de valores
    -- USO: Usada para encriptar contraseas
    -- OBSERVACIONES: Al realizar login, encriptamos la contrasea y la comparamos 
    --                con el valor encriptado de la tabla (GSU_USUARIO.USR_PASS)
    --
    
    AUX GCU_USUARIO.USR_PASS%Type; 
    
BEGIN 
        
    AUX:= SYS.DBMS_OBFUSCATION_TOOLKIT.MD5 (INPUT => UTL_RAW.CAST_TO_RAW(VALOR));
    
    RETURN RAWTOHEX(AUX);
    
END;
/


CREATE OR REPLACE FUNCTION     FUN_GET_CONID_BY_USER (p_USERID NUMBER) RETURN NUMBER IS
    --
    -- DESCRIPCIN: Funcin que obtiene el concesionario del usuario conectado
    -- USO: Usada para guardar el concesionario en el vehculo a la hora de crearlo. 
    -- OBSERVACIONES: Cuando un empleado inserta un vehculo este pasa a formar parte del inventario del concesionario
    --               al que pertenece dicho usuario
    --
    
    
    --
    -- Obtiene id de concesionario
    --
    Cursor c_CONCESIONARIO Is
    Select EMP_CONID
    From GCU_EMPLEADO
    JOIN GCU_USUARIO ON EMP_ID = USR_EMPID
    Where USR_ID = p_USERID; 
    
    v_CONID GCU_EMPLEADO.EMP_CONID%Type;   
    
BEGIN 
        
    Open c_CONCESIONARIO; 
    Fetch c_CONCESIONARIO Into v_CONID;
    Close c_CONCESIONARIO;  
    
    IF v_CONID Is Null Then
        raise_application_error (-20037,'Error al obtener el concesionario'); 
    End If; 

    return v_CONID; 

Exception WHEN OTHERS THEN
    
    Raise_Application_Error(-20038, 'Error al obtener el concesionario del usuario '||p_USERID);
        
END;
/


CREATE OR REPLACE FUNCTION     FUN_GET_TIPEMP_BY_USER (p_USERID NUMBER) RETURN NUMBER IS
    --
    -- DESCRIPCIN: Funcin que obtiene el tipo de empleado del usuario conectado
    -- USO: Usada al guardar un nuevo vehculo. 
    -- 
    
    --
    -- Obtiene tipo de empleado
    --
    Cursor c_TIPOEMP Is
    Select EMP_TIPOEMP
    From GCU_EMPLEADO
    JOIN GCU_USUARIO ON EMP_ID = USR_EMPID
    Where USR_ID = p_USERID; 
    
    v_TIPOEMP GCU_EMPLEADO.EMP_TIPOEMP%Type;   
    
BEGIN 
        
    Open c_TIPOEMP; 
    Fetch c_TIPOEMP Into v_TIPOEMP;
    Close c_TIPOEMP;  

    return v_TIPOEMP; 

Exception WHEN OTHERS THEN
    
    Raise_Application_Error(-20036, 'Error al obtener el tipo de empleado del usuario '||p_USERID);
        
END;
/


CREATE OR REPLACE FUNCTION     FUN_GET_TOTAL_FACTURA (p_FACID NUMBER) RETURN NUMBER IS
    --
    -- DESCRIPCIN: Funcin que obtiene el importe total de la factura
    -- USO: Usada para los informes DWH. 
    --
  
v_TOTAL Number; 
  
BEGIN 
        
    Select SUM(NVL(LIN_PVP,0)) 
    Into v_TOTAL
    From GCU_LINEAFACTURA
    Where LIN_FACID = p_FACID;
    
    Return v_TOTAL; 

Exception WHEN OTHERS THEN
    
    Raise_Application_Error(-20035, 'Error al obtener el obtener el importe total de la factura. '||p_FACID);
        
END;
/